==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.18.jar: sources/QtJambi3DCore/QStaticPropertyUpdatedChangeBase_shell.cpp <==
#include "QStaticPropertyUpdatedChangeBase_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QStaticPropertyUpdatedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QStaticPropertyUpdatedChangeBase")
    Qt3DCore::QStaticPropertyUpdatedChangeBase *_ptr = reinterpret_cast<Qt3DCore::QStaticPropertyUpdatedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QStaticPropertyUpdatedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStaticPropertyUpdatedChangeBase_shell) ); }

jmethodID QStaticPropertyUpdatedChangeBase_shell::__shell_javaMethod(int pos) const { return QStaticPropertyUpdatedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase), pos); }

// emitting (writeShellConstructor)
QStaticPropertyUpdatedChangeBase_shell::QStaticPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QStaticPropertyUpdatedChangeBase(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::QStaticPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)", QStaticPropertyUpdatedChangeBase_shell::__shell())
    QStaticPropertyUpdatedChangeBase_shell::__shell()->constructed(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase));
}

// emitting (writeShellDestructor)
QStaticPropertyUpdatedChangeBase_shell::~QStaticPropertyUpdatedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::~Qt3DCore::QStaticPropertyUpdatedChangeBase()", QStaticPropertyUpdatedChangeBase_shell::__shell())
    QStaticPropertyUpdatedChangeBase_shell::__shell()->destructed(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase));
}

void QStaticPropertyUpdatedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStaticPropertyUpdatedChangeBase_shell*>(ptr)->QStaticPropertyUpdatedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QStaticPropertyUpdatedChangeBase_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QStaticPropertyUpdatedChangeBase *__qt_this = new(__qtjambi_ptr) QStaticPropertyUpdatedChangeBase_shell(__qt_subjectId0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStaticPropertyUpdatedChangeBase_shell
void __qt_destruct_Qt3DCore_QStaticPropertyUpdatedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QStaticPropertyUpdatedChangeBase")
    reinterpret_cast<QStaticPropertyUpdatedChangeBase_shell*>(ptr)->~QStaticPropertyUpdatedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QStaticPropertyUpdatedChangeBase::QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_initialize_1native__Lio_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QStaticPropertyUpdatedChangeBase_0, sizeof(QStaticPropertyUpdatedChangeBase_shell), typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase), true, &deleter_Qt3DCore_QStaticPropertyUpdatedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QStaticPropertyUpdatedChangeBase::propertyName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_propertyName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QStaticPropertyUpdatedChangeBase *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QStaticPropertyUpdatedChangeBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::propertyName()const", __qt_this)
        const char* __qt_return_value = __qt_this->propertyName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QStaticPropertyUpdatedChangeBase::setPropertyName(const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_setPropertyName_1native_1const_1char_1ptr__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QStaticPropertyUpdatedChangeBase *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QStaticPropertyUpdatedChangeBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::setPropertyName(const char*)", __qt_this)
        const char*  __qt_name0 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, name0);
        __qt_this->setPropertyName(__qt_name0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QStaticPropertyUpdatedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QStaticPropertyUpdatedChangeBase>("Qt3DCore::QStaticPropertyUpdatedChangeBase", "io/qt/qt3d/core/QStaticPropertyUpdatedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QStaticPropertyUpdatedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QStaticPropertyUpdatedChangeBase_0, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QStaticPropertyUpdatedChangeBase);
    registerSizeOfShell(typeId, sizeof(QStaticPropertyUpdatedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QPropertyUpdatedChangeBase, Qt3DCore::QStaticPropertyUpdatedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.20.jar: sources/QtJambi3DCore/QStaticPropertyUpdatedChangeBase_shell.cpp <==
#include "QStaticPropertyUpdatedChangeBase_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QStaticPropertyUpdatedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QStaticPropertyUpdatedChangeBase")
    Qt3DCore::QStaticPropertyUpdatedChangeBase *_ptr = reinterpret_cast<Qt3DCore::QStaticPropertyUpdatedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QStaticPropertyUpdatedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStaticPropertyUpdatedChangeBase_shell) ); }

jmethodID QStaticPropertyUpdatedChangeBase_shell::__shell_javaMethod(int pos) const { return QStaticPropertyUpdatedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase), pos); }

// emitting (writeShellConstructor)
QStaticPropertyUpdatedChangeBase_shell::QStaticPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QStaticPropertyUpdatedChangeBase(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::QStaticPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)", QStaticPropertyUpdatedChangeBase_shell::__shell())
    QStaticPropertyUpdatedChangeBase_shell::__shell()->constructed(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase));
}

// emitting (writeShellDestructor)
QStaticPropertyUpdatedChangeBase_shell::~QStaticPropertyUpdatedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::~Qt3DCore::QStaticPropertyUpdatedChangeBase()", QStaticPropertyUpdatedChangeBase_shell::__shell())
    QStaticPropertyUpdatedChangeBase_shell::__shell()->destructed(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase));
}

void QStaticPropertyUpdatedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStaticPropertyUpdatedChangeBase_shell*>(ptr)->QStaticPropertyUpdatedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QStaticPropertyUpdatedChangeBase_Qt3DCore_QNodeId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QStaticPropertyUpdatedChangeBase *__qt_this = new(__qtjambi_ptr) QStaticPropertyUpdatedChangeBase_shell(__qt_subjectId0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QStaticPropertyUpdatedChangeBase::QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_initialize_1native__Lio_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QStaticPropertyUpdatedChangeBase_Qt3DCore_QNodeId, sizeof(QStaticPropertyUpdatedChangeBase_shell), typeid(Qt3DCore::QStaticPropertyUpdatedChangeBase), true, &deleter_Qt3DCore_QStaticPropertyUpdatedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStaticPropertyUpdatedChangeBase_shell
void __qt_destruct_Qt3DCore_QStaticPropertyUpdatedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QStaticPropertyUpdatedChangeBase")
    reinterpret_cast<QStaticPropertyUpdatedChangeBase_shell*>(ptr)->~QStaticPropertyUpdatedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QStaticPropertyUpdatedChangeBase::propertyName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_propertyName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QStaticPropertyUpdatedChangeBase *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QStaticPropertyUpdatedChangeBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::propertyName()const", __qt_this)
        const char* __qt_return_value = __qt_this->propertyName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QStaticPropertyUpdatedChangeBase::setPropertyName(const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QStaticPropertyUpdatedChangeBase_setPropertyName_1native_1const_1char_1ptr__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QStaticPropertyUpdatedChangeBase *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QStaticPropertyUpdatedChangeBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QStaticPropertyUpdatedChangeBase::setPropertyName(const char*)", __qt_this)
        const char*  __qt_name0 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, name0);
        __qt_this->setPropertyName(__qt_name0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QStaticPropertyUpdatedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QStaticPropertyUpdatedChangeBase>("Qt3DCore::QStaticPropertyUpdatedChangeBase", "io/qt/qt3d/core/QStaticPropertyUpdatedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QStaticPropertyUpdatedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QStaticPropertyUpdatedChangeBase_Qt3DCore_QNodeId, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QStaticPropertyUpdatedChangeBase);
    registerSizeOfShell(typeId, sizeof(QStaticPropertyUpdatedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QPropertyUpdatedChangeBase, Qt3DCore::QStaticPropertyUpdatedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
